@@ -29,9 +29,8 @@ most of its code.
 
 =cut
 
-# use Sepia '_apropos_re';
-require Sepia;
 BEGIN { *_apropos_re = *Sepia::_apropos_re; }
+$VERSION = '0.64';
 
 use strict;
 use Config;
@@ -39,8 +38,8 @@ use Cwd 'abs_path';
 use B qw(peekop class comppadlist main_start svref_2object walksymtable
          OPpLVAL_INTRO SVf_POK OPpOUR_INTRO OPf_MOD OPpDEREF_HV OPpDEREF_AV
 	 cstring);
-# stupid warnings...
-no warnings 'uninitialized';
+# use Sepia '_apropos_re';
+require Sepia;
 
 =head2 Variables
 
@@ -73,10 +72,11 @@ our %var_def;
 our %var_use;
 
 require Exporter;
-our @ISA = 'Exporter';
+our @ISA = qw(Exporter);
 my @most = qw(redefined forget rebuild callers callees
 	      var_defs var_uses
-	      var_apropos);
+	      mod_subs mod_files mod_decls mod_apropos
+	      apropos var_apropos file_apropos);
 our @EXPORT_OK = (@most,
     qw(xref_definitions xref_object xref_main
        %call %callby %var_use %var_def));
@@ -114,9 +114,6 @@ my %code = (intro => "i", used => "",
 	    subdef => "s", subused => "&",
 	    formdef => "f", meth => "->");
 
-=head2 Functions
-
-=over 4
 
 =item C<guess_module_file($pack, $ofile)>
 
@@ -134,7 +131,6 @@ sub guess_module_file {
     return undef if $ofile =~ /Exporter\.pm$/;
     # Try for standard translation in %INC:
     (my $fn = $pack) =~ s/::/\//g;
-    return unless $fn;          # stupid warnings...
     if (exists $INC{"$fn.pm"}) {
 	return $INC{"$fn.pm"};
     }
@@ -206,6 +202,7 @@ sub process {
 	my ($spack, $sname) = split_name($subname);
 
 	$call{$name}{$pack}{$subname} = 1;
+
 	$callby{$sname}{$spack}{"$pack\::$name"} = 1;
     } elsif ($type eq 's' || $subname eq '(definitions)') {
 	# definition
@@ -259,14 +256,6 @@ sub load_pad {
 	    next unless class($valsv) eq "GV";
 	    # these pad GVs don't have corresponding names, so same @pad
 	    # array can be used without collisions
-
-            # XXX: for some reason, on 5.10 $valsv->STASH can be a
-            # B::SPECIAL, which doesn't have a name.
-
-            # XXX: this segfaults on 5.10 for some reason while
-            # traversing File::Find::contract_name from main
-
-            next if ref $valsv->STASH eq 'B::SPECIAL';
 	    $pad[$ix] = [$valsv->STASH->NAME, "*", $valsv->NAME];
 	}
     }
@@ -295,6 +284,7 @@ sub xref {
 	    xref($op->pmreplstart);
 	} else {
 	    no strict 'refs';
+#             print STDERR $opname;
 	    my $ppname = "pp_$opname";
 	    &$ppname($op) if defined(&$ppname);
 	}
@@ -440,7 +430,7 @@ sub pp_method_named {
 	$top = [$lastclass || "(method)", '->', $name];
 	undef $lastclass;
     } else {
-	dprint 'method_named', "method_named: wtf: sizeof padval = ".@padval;
+	warn "method_named: wtf: sizeof padval = ".@padval;
     }
 }
 
@@ -500,6 +490,10 @@ sub xref_definitions {
     walksymtable(\%{"main::"}, "xref", sub { !xref_exclude($_[0]) });
 }
 
+=head2 Functions
+
+=over
+
 =item C<rebuild()>
 
 Rebuild the Xref database.
@@ -612,8 +606,7 @@ sub _var_ret_list
     if ($mod) {
         @r = exists $h->{$mod} ? @{$h->{$mod}} : ();
     } else {
-        ## XXX: Need to revisit when this is/isn't an array!
-        @r = map { ref $_ eq 'ARRAY' ? @$_ : $_ } values %$h;
+       @r = map { @$_ } values %$h;
     }
     @r = grep $_->{assign}, @r if $assign;
     @r = map { [@{$_}{qw(file line sub package)}] } @r;
@@ -679,13 +672,10 @@ List the modules defined in file C<$file>.
 
 sub file_modules {
     my $file = shift;
-    eval {
-        require Module::Info;
-        my $mod = Module::Info->new_from_file(abs_path($file));
-        if ( $mod ) {
-            return $mod->packages_inside();
-        }
-    }
+    eval "use Module::Include;" and do {
+        my $mod = Module::Include->new_from_file(abs_path($file));
+        return ($mod && $mod->packages_inside) || undef;
+    };
 }
 
 =item C<var_apropos($expr)>
